<?php
/**
 * Gestion du formulaire de d'édition d'une subdivision
 *
 * @plugin     Subdivisions Géographiques
 * @copyright  2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Subdivisions\Formulaires
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

include_spip('inc/actions');
include_spip('inc/editer');

/**
 * Un simple formulaire de déclaration des saisies
 *
 * Utilisation du plugin Saisies
 *
 * @return array
 *     tableau décrivant les saisies à afficher dans le formulaire de configuration
 **/
 
function formulaires_subdivision_saisies(){
	$saisies = array(
		array( 
			'saisie' => 'hidden',
			'options' => array(
			'nom' => 'id_subdivision'
			)
		),
		array( 
			'saisie' => 'hidden',
			'options' => array(
				'nom' => 'retour',
			)
		),
		array( 
			'saisie' => 'textarea',
			'options' => array(
				'nom' => 'nom_usage',
				'label' => _T('subdivision:label_nom_usage'),
 				'placeholder' => '&lt;multi&gt;[fr]en français[en]in english</multi>'
			),
			'verifier' => array(
				'type' => 'regex',
				'options' => array(
					'modele' => '#<multi>(.+)</multi>#isU'
				)
			)
		)
	);

	return $saisies;
}

/**
 * Identifier le formulaire en faisant abstraction des paramètres qui ne représentent pas l'objet édité
 *
 * @param int|string $id_subdivision
 *     Identifiant de la subdivision. 'new' pour une nouvelle subdivision.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return string
 *     Hash du formulaire
 */
function formulaires_editer_subdivision_identifier_dist($id_subdivision = 'new', $id_pays = 0, $retour = '',  $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {
	return serialize(array(intval($id_subdivision), $associer_objet));
}

/**
 * Chargement du formulaire d'édition de subdivision
 *
 * Déclarer les champs postés et y intégrer les valeurs par défaut
 *
 * @uses formulaires_editer_objet_charger()
 *
 * @param int|string $id_subdivision
 *     Identifiant de la subdivision. 'new' pour une nouvelle subdivision.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Environnement du formulaire
 */
function formulaires_editer_subdivision_charger_dist($id_subdivision = 'new', $id_parent = 0, $retour = '', $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {

	$valeurs = formulaires_editer_objet_charger('subdivision', $id_subdivision, $id_parent, $lier_trad, $retour, $config_fonc, $row, $hidden);
	
	$valeurs['retour'] = $retour;

	// transmettre les listes au plugin Saisies pour formulaires

	$valeurs['_mes_saisies'] = formulaires_subdivision_saisies();
	
	return $valeurs;
}

/**
 * Vérifications du formulaire d'édition de subdivision
 *
 * Vérifier les champs postés et signaler d'éventuelles erreurs
 *
 * @uses formulaires_editer_objet_verifier()
 *
 * @param int|string $id_subdivision
 *     Identifiant de la subdivision. 'new' pour une nouvelle subdivision.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Tableau des erreurs
 */
function formulaires_editer_subdivision_verifier_dist($id_subdivision = 'new', $id_parent = 0, $retour = '',  $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {

	$erreurs = formulaires_editer_objet_verifier('id_subdivision', $id_subdivision);

	// on va chercher le pipeline saisies_verifier() dans son fichier
	include_spip('inc/saisies');
 
	// on charge les saisies
	$mes_saisies = formulaires_subdivision_saisies();
 
	// saisies_verifier retourne un tableau des erreurs s'il y en a, sinon traiter() prend le relais
	$erreurs = saisies_verifier($mes_saisies);

	return $erreurs;

}

/**
 * Traitement du formulaire d'édition de subdivision
 *
 * Traiter les champs postés
 *
 * @uses formulaires_editer_objet_traiter()
 *
 * @param int|string $id_subdivision
 *     Identifiant de la subdivision. 'new' pour un nouveau paiement.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Retours des traitements
 */
function formulaires_editer_subdivision_traiter_dist($id_subdivision = 'new', $id_parent = 0, $retour = '',  $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {

	$retours = formulaires_editer_objet_traiter('subdivision', $id_subdivision, $id_parent, $lier_trad, $retour, $config_fonc, $row, $hidden);
		
	return $retours;
}
